==> chirontt-eclipse.platform.ui-R4_37_maintenance_GH0.tar.gz: eclipse.platform.ui-R4_37_maintenance/tests/org.eclipse.ui.tests.performance/src/org/eclipse/ui/tests/performance/GenerateIdentifiersTest.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2007 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.ui.tests.performance;

import static org.eclipse.ui.PlatformUI.getWorkbench;

import org.eclipse.ui.activities.IActivityManager;
import org.junit.ClassRule;
import org.junit.Test;

/**
 * @since 3.1
 */
public class GenerateIdentifiersTest extends BasicPerformanceTest {

	@ClassRule
	public static final UIPerformanceTestRule uiPerformanceTestRule = new UIPerformanceTestRule();

	private static final int count = 10000;

	@Test
	public void test() throws Throwable {
		final IActivityManager activityManager = getWorkbench().getActivitySupport().getActivityManager();

		exercise(() -> {
			// construct the Identifiers to test
			final String[] ids = new String[count];
			for (int i = 0; i < ids.length; i++) {
				long timestamp = System.currentTimeMillis();
				ids[i] = "org.eclipse.jdt.ui/" + i + timestamp;
			}

			startMeasuring();
			for (String id : ids) {
				activityManager.getIdentifier(id);
			}
			stopMeasuring();
		});
		commitMeasurements();
		assertPerformance();
	}
}

==> chirontt-eclipse.platform.ui-R4_38_maintenance_GH0.tar.gz: eclipse.platform.ui-R4_38_maintenance/tests/org.eclipse.ui.tests.performance/src/org/eclipse/ui/tests/performance/GenerateIdentifiersTest.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2007 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.ui.tests.performance;

import static org.eclipse.ui.PlatformUI.getWorkbench;
import static org.eclipse.ui.tests.performance.UIPerformanceTestUtil.exercise;

import org.eclipse.test.performance.PerformanceTestCaseJunit4;
import org.eclipse.ui.activities.IActivityManager;
import org.eclipse.ui.tests.harness.util.CloseTestWindowsRule;
import org.junit.ClassRule;
import org.junit.Rule;
import org.junit.Test;

/**
 * @since 3.1
 */
public class GenerateIdentifiersTest extends PerformanceTestCaseJunit4 {

	@ClassRule
	public static final UIPerformanceTestRule uiPerformanceTestRule = new UIPerformanceTestRule();

	@Rule
	public final CloseTestWindowsRule closeTestWindows = new CloseTestWindowsRule();

	private static final int count = 10000;

	@Test
	public void test() throws Throwable {
		final IActivityManager activityManager = getWorkbench().getActivitySupport().getActivityManager();

		exercise(() -> {
			// construct the Identifiers to test
			final String[] ids = new String[count];
			for (int i = 0; i < ids.length; i++) {
				long timestamp = System.currentTimeMillis();
				ids[i] = "org.eclipse.jdt.ui/" + i + timestamp;
			}

			startMeasuring();
			for (String id : ids) {
				activityManager.getIdentifier(id);
			}
			stopMeasuring();
		});
		commitMeasurements();
		assertPerformance();
	}
}
